==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1beta1LeaseFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1beta1LeaseFluent<A extends V1beta1LeaseFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1LeaseFluent.MetadataNested<A> withNewMetadata();
    public V1beta1LeaseFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1LeaseFluent.MetadataNested<A> editMetadata();
    public V1beta1LeaseFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1LeaseFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1LeaseSpec getSpec();
    public V1beta1LeaseSpec buildSpec();
    public A withSpec(V1beta1LeaseSpec spec);
    public Boolean hasSpec();
    public V1beta1LeaseFluent.SpecNested<A> withNewSpec();
    public V1beta1LeaseFluent.SpecNested<A> withNewSpecLike(V1beta1LeaseSpec item);
    public V1beta1LeaseFluent.SpecNested<A> editSpec();
    public V1beta1LeaseFluent.SpecNested<A> editOrNewSpec();
    public V1beta1LeaseFluent.SpecNested<A> editOrNewSpecLike(V1beta1LeaseSpec item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1LeaseFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1LeaseSpecFluent<V1beta1LeaseFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1LeaseFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1beta1LeaseFluent<A extends V1beta1LeaseFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1LeaseFluent.MetadataNested<A> withNewMetadata();
    public V1beta1LeaseFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1LeaseFluent.MetadataNested<A> editMetadata();
    public V1beta1LeaseFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1LeaseFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1LeaseSpec getSpec();
    public V1beta1LeaseSpec buildSpec();
    public A withSpec(V1beta1LeaseSpec spec);
    public Boolean hasSpec();
    public V1beta1LeaseFluent.SpecNested<A> withNewSpec();
    public V1beta1LeaseFluent.SpecNested<A> withNewSpecLike(V1beta1LeaseSpec item);
    public V1beta1LeaseFluent.SpecNested<A> editSpec();
    public V1beta1LeaseFluent.SpecNested<A> editOrNewSpec();
    public V1beta1LeaseFluent.SpecNested<A> editOrNewSpecLike(V1beta1LeaseSpec item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1LeaseFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1LeaseSpecFluent<V1beta1LeaseFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}
